==> rhb-vertx-4.1.5-src.zip: rhb-vertx-4.1.5.GA-src/io.vertx-vertx-auth-4.1.5/vertx-auth-jdbc/src/main/java/io/vertx/ext/auth/jdbc/impl/PBKDF2Strategy.java <==
package io.vertx.ext.auth.jdbc.impl;

import io.vertx.core.Vertx;
import io.vertx.core.VertxException;
import io.vertx.ext.auth.jdbc.JDBCHashStrategy;

import javax.crypto.SecretKeyFactory;
import javax.crypto.spec.PBEKeySpec;
import java.nio.charset.StandardCharsets;
import java.security.NoSuchAlgorithmException;
import java.security.spec.InvalidKeySpecException;

@Deprecated
public class PBKDF2Strategy extends AbstractHashingStrategy implements JDBCHashStrategy {

  private static final int DEFAULT_ITERATIONS = 10000;
  private final SecretKeyFactory skf;

  public PBKDF2Strategy(Vertx vertx) {
    super(vertx);

    try {
      skf = SecretKeyFactory.getInstance("PBKDF2WithHmacSHA512");
    } catch (NoSuchAlgorithmException nsae) {
      throw new RuntimeException("PBKDF2 is not available", nsae);
    }
  }

  @Override
  public String computeHash(String password, String salt, int version) {

    int iterations = DEFAULT_ITERATIONS;

    if (version >= 0) {
      if (nonces == null) {
        // the nonce version is not available
        throw new VertxException("nonces are not available");
      }

      if (version < nonces.size()) {
        iterations = nonces.getInteger(version);
      }
    }

    PBEKeySpec spec = new PBEKeySpec(
      password.toCharArray(),
      salt.getBytes(StandardCharsets.UTF_8),
      iterations,
      64 * 8);

    try {
      byte[] hash = skf.generateSecret(spec).getEncoded();

      if (version >= 0) {
        return bytesToHex(hash) + '$' + version;
      } else {
        return bytesToHex(hash);
      }

    } catch (InvalidKeySpecException ikse) {
      throw new VertxException(ikse);
    }
  }
}

==> rhb-vertx-4.2.5-src.zip: rhb-vertx-4.2.5.GA-src/io.vertx-vertx-auth-4.2.5/vertx-auth-jdbc/src/main/java/io/vertx/ext/auth/jdbc/impl/PBKDF2Strategy.java <==
package io.vertx.ext.auth.jdbc.impl;

import io.vertx.core.Vertx;
import io.vertx.core.VertxException;
import io.vertx.ext.auth.jdbc.JDBCHashStrategy;

import javax.crypto.SecretKeyFactory;
import javax.crypto.spec.PBEKeySpec;
import java.nio.charset.StandardCharsets;
import java.security.NoSuchAlgorithmException;
import java.security.spec.InvalidKeySpecException;

import static io.vertx.ext.auth.impl.Codec.base16Encode;

@Deprecated
public class PBKDF2Strategy extends AbstractHashingStrategy implements JDBCHashStrategy {

  private static final int DEFAULT_ITERATIONS = 10000;
  private final SecretKeyFactory skf;

  public PBKDF2Strategy(Vertx vertx) {
    super(vertx);

    try {
      skf = SecretKeyFactory.getInstance("PBKDF2WithHmacSHA512");
    } catch (NoSuchAlgorithmException nsae) {
      throw new RuntimeException("PBKDF2 is not available", nsae);
    }
  }

  @Override
  public String computeHash(String password, String salt, int version) {

    int iterations = DEFAULT_ITERATIONS;

    if (version >= 0) {
      if (nonces == null) {
        // the nonce version is not available
        throw new VertxException("nonces are not available");
      }

      if (version < nonces.size()) {
        iterations = nonces.getInteger(version);
      }
    }

    PBEKeySpec spec = new PBEKeySpec(
      password.toCharArray(),
      salt.getBytes(StandardCharsets.UTF_8),
      iterations,
      64 * 8);

    try {
      byte[] hash = skf.generateSecret(spec).getEncoded();

      if (version >= 0) {
        return base16Encode(hash).toUpperCase() + '$' + version;
      } else {
        return base16Encode(hash).toUpperCase();
      }

    } catch (InvalidKeySpecException ikse) {
      throw new VertxException(ikse);
    }
  }
}
